from unittest.mock import patch

import pytest

from gso.products.product_blocks.router import RouterRole
from gso.products.product_types.router import Router
from test.services.conftest import MockedKentikClient
from test.workflows import assert_complete, extract_state, run_workflow


@pytest.mark.workflow()
@patch("gso.services.kentik_client.KentikClient")
def test_modify_router_kentik_license_success(
    mock_kentik_client,
    router_subscription_factory,
    faker,
):
    #  Set up mock return values
    product_id = router_subscription_factory(router_role=RouterRole.PE)
    mock_kentik_client.return_value = MockedKentikClient

    #  Run workflow
    initial_input_data = [{"subscription_id": product_id}, {"new_plan_id": "0"}]
    result, _, _ = run_workflow("modify_router_kentik_license", initial_input_data)

    assert_complete(result)

    state = extract_state(result)
    subscription_id = state["subscription_id"]
    subscription = Router.from_subscription(subscription_id)
    assert subscription.status == "active"
